"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const crypto_1 = __importDefault(require("crypto"));
const qs_1 = __importDefault(require("qs"));
const axios_1 = __importDefault(require("axios"));
exports.generateSignature = (path, secret) => {
    return crypto_1.default
        .createHmac('sha512', secret)
        .update(path)
        .digest('hex');
};
const prefix = 'https://api.bittrex.com/api/v1.1';
exports.publicRequest = (method, params = {}) => __awaiter(this, void 0, void 0, function* () {
    const path = `/${method}`;
    try {
        const response = yield axios_1.default.get(`${prefix}${path}`, { params });
        return response.data;
    }
    catch (e) {
        const error = new Error('Failed to execute request on exchange.');
        error.original = e;
        throw error;
    }
});
exports.privateRequest = (method, auth, params = {}) => __awaiter(this, void 0, void 0, function* () {
    const path = `${prefix}/${method}`;
    const nonce = Date.now() * 1000;
    const query = qs_1.default.stringify(Object.assign({}, params, { nonce, apiKey: auth.key }));
    const message = `${path}?${query}`;
    const signature = exports.generateSignature(message, auth.secret);
    try {
        const response = yield axios_1.default.get(message, {
            headers: {
                apisign: signature,
            },
        });
        return response.data;
    }
    catch (e) {
        const error = new Error('Failed to execute request on exchange.');
        error.original = e;
        throw error;
    }
});
